@@ -1,4 +1,5 @@
 """Chit Chat Challenge dataset."""
+import itertools
 import json
 import os
 from typing import Iterable, Iterator, Tuple
@@ -43,15 +44,15 @@ class CompoundingConversationDataset:
     def __init__(
         self,
         path: str = _PATH,
-        odd_speaker_token: str = "<speaker1>",
-        even_speaker_token: str = "<speaker2>",
+        first_speaker_token: str = "<speaker1>",
+        second_speaker_token: str = "<speaker2>",
         end_of_utterance_token: str = " ",
         prefix: str = "",
     ) -> None:
         """Instantiates a new ConversationDataset object."""
         self.path = path
-        self.odd_speaker_token = odd_speaker_token
-        self.even_speaker_token = even_speaker_token
+        self.first_speaker_token = first_speaker_token
+        self.second_speaker_token = second_speaker_token
         self.eou_token = end_of_utterance_token
         self.prefix = prefix
         self._data = json.load(open(self.path))
@@ -61,7 +62,7 @@ class CompoundingConversationDataset:
         for conv in self._data.values():
             conv = [self.eou_token.join(u["text"] for u in m) for m in conv["messages"]]
             for example in compound_conversation(
-                conv, self.odd_speaker_token, self.even_speaker_token, self.prefix
+                conv, self.first_speaker_token, self.second_speaker_token, self.prefix
             ):
                 yield example
 
@@ -88,8 +89,8 @@ class MessageDataset:
 
 def compound_conversation(
     convo: Iterable[str],
-    odd_speaker_token: str,
-    even_speaker_token: str,
+    first_speaker_token: str,
+    second_speaker_token: str,
     prefix: str = "",
 ) -> Iterator[Tuple[str, str]]:
     """Compounds a single conversation.
@@ -101,22 +102,20 @@ def compound_conversation(
         ("<s1>message1<s2>message2", "<s1>message3")
         ("<s1>message1<s2>message2<s1>message3", "<s2>message4")
 
-    Where: ``<s1>`` denotes the ``odd_speaker_token`` and 
-    ``<s2>`` denotes the ``even_speaker_token``
+    Where: ``<s1>`` denotes the ``first_speaker_token`` and
+    ``<s2>`` denotes the ``second_speaker_token``.
     """
-    # NB: switch even and odd tokens because we start at 1
-    even_token = odd_speaker_token
-    odd_token = even_speaker_token
+    first_tok = first_speaker_token
+    second_tok = second_speaker_token
 
     convo = list(convo)
     for i in range(1, len(convo)):
-        c = "".join(add_alternating_tokens(convo[:i], odd_token, even_token))
-        yield prefix + c, even_token + convo[i] if i % 2 == 0 else odd_token + convo[i]
+        c = "".join(prepend_cycle(convo[:i], [first_tok, second_tok]))
+        yield prefix + c, first_tok + convo[i] if i % 2 == 0 else second_tok + convo[i]
 
 
-def add_alternating_tokens(
-    convo: Iterable[str], odd_token: str, even_token: str,
-) -> Iterator[str]:
-    """Adds alternating tokens to an iterable (list) of strings."""
-    for i, s in enumerate(convo):
-        yield even_token + s if i % 2 == 0 else odd_token + s
+# TODO: should this even be a function?  # noqa: W0511
+def prepend_cycle(texts: Iterable[str], cycle: Iterable[str]) -> Iterator[str]:
+    """Prepends an element of ``cycle`` in order to each element of ``texts``."""
+    for token, text in zip(itertools.cycle(cycle), texts):
+        yield token + text
